Module ops

Module ops 

GAT equivalents of std operators

Traits

Index
Index operator for immutable contexts. As opposed to std, the returned value can be a non-reference. This allows custom reference types for things like multi-dimensional matrices.
IndexMut
Index operator for mutable contexts. As opposed to std, the returned value can be a non-reference. This allows custom reference types for things like multi-dimensional matrices.