pub trait Index<T> {
type Output<'a>
where Self: 'a;
// Required method
fn index(&self, idx: T) -> Self::Output<'_>;
}Expand description
Index operator for immutable contexts. As opposed to std, the returned value can be a
non-reference. This allows custom reference types for things like multi-dimensional matrices.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".