pub trait IndexMut<T>: Index<T> {
type OutputMut<'a>
where Self: 'a;
// Required method
fn index_mut(&mut self, idx: T) -> Self::OutputMut<'_>;
}Expand description
Index operator for mutable contexts. As opposed to std, the returned value can be a
non-reference. This allows custom reference types for things like multi-dimensional matrices.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".